Summary:       Open Virtual Machine Tools for virtual machines hosted on VMware
Name:          open-vm-tools
Version:       12.2.5
Release:       1%{?dist}
License:       GPLv2
URL:           https://github.com/vmware/%{name}
Source0:       %{url}/archive/refs/tags/stable-%{version}.tar.gz

Source1:       vmtoolsd.service
Source2:       vgauthd.service
Source3:       run-vmblock\x2dfuse.mount
Source4:       open-vm-tools.conf
Source5:       vmtoolsd.pam

BuildRequires: autoconf automake libtool
BuildRequires: make gcc-c++ doxygen fuse-devel glib2-devel libicu-devel
BuildRequires: libmspack-devel libtool-ltdl-devel libX11-devel libXext-devel libXi-devel
BuildRequires: libXinerama-devel libXrandr-devel libXrender-devel libXtst-devel openssl-devel
BuildRequires: pam-devel pkgconfig(libdrm) pkgconfig(libudev) procps-devel xmlsec1-openssl-devel
BuildRequires: gdk-pixbuf2-xlib-devel gtk3-devel gtkmm30-devel libtirpc-devel rpcgen systemd-udev
Requires: coreutils fuse iproute grep
Requires: pciutils sed systemd tar util-linux which xmlsec1-openssl
ExclusiveArch: x86_64 aarch64

%description
The %{name} project is an open source implementation of VMware Tools. It is a suite of open source
virtualization utilities and drivers to improve the functionality, user experience and
administration of VMware virtual machines.  This package contains only the core user-space programs
and libraries of %{name}.

%package          desktop
Summary:          User experience components for Open Virtual Machine Tools
Requires:         %{name} = %{version}-%{release}

%description      desktop
This package contains only the user-space programs and libraries of %{name} that are essential for
improved user experience of VMware virtual machines.

%package          sdmp
Summary:          Service Discovery components for Open Virtual Machine Tools
Requires:         %{name} = %{version}-%{release}
Requires:         coreutils gawk glibc-common grep iproute procps

%description      sdmp
This package contains only the user-space programs and utility scripts of %{name} that are essential
for performing service discovery in VMware virtual machines by vRealize Operations Service Discovery
Management Pack.

%package          salt-minion
Summary:          Script file to install/uninstall salt-minion
Requires:         %{name} = %{version}-%{release}, systemd, curl, coreutils, gawk, grep
ExclusiveArch:    x86_64

%description      salt-minion
This package contains a script to setup Salt Minion on VMware virtual machines.

%package          devel
Summary:          Development libraries for Open Virtual Machine Tools
Requires:         %{name} = %{version}-%{release}

%description      devel
This package contains only the user-space programs and libraries of %{name} that are essential for
developing customized applications for VMware virtual machines.

%prep
%autosetup -p1 -n %{name}-stable-%{version}
mv %{name}/* .

%build
autoreconf -vif

%configure \
    --without-kernel-modules \
    --enable-xmlsec1 \
    --enable-resolutionkms \
    --enable-servicediscovery \
    --with-tirpc \
    --without-gtk2 \
    --without-gtkmm \
    --disable-static \
%ifarch x86_64
    --enable-salt-minion \
%endif
    %{nil}

sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool
%make_build

%install
export DONT_STRIP=1
%make_install

chmod a-x %{buildroot}%{_sysconfdir}/pam.d/*
chmod a-x %{buildroot}%{_sysconfdir}/vmware-tools/*.conf
chmod a-x %{buildroot}%{_sysconfdir}/vmware-tools/vgauth/schemas/*
chmod a-x %{buildroot}%{_udevrulesdir}/99-vmware-scsi-udev.rules

sed -i "s|^Encoding.*$||g" %{buildroot}%{_sysconfdir}/xdg/autostart/vmware-user.desktop

find %{buildroot}%{_libdir} -name '*.la' -delete
rm -fr %{buildroot}%{_defaultdocdir}
rm -f docs/api/build/html/FreeSans.ttf
rm -fr %{buildroot}%{_sbindir} %{buildroot}/sbin/mount.vmhgfs

install -p -m 644 -D %{SOURCE1} %{buildroot}%{_unitdir}/vmtoolsd.service
install -p -m 644 -D %{SOURCE2} %{buildroot}%{_unitdir}/vgauthd.service
install -p -m 644 -D '%{SOURCE3}' %{buildroot}%{_unitdir}/run-vmblock\\x2dfuse.mount
install -p -m 644 -D %{SOURCE4} %{buildroot}%{_modulesloaddir}/open-vm-tools.conf
install -p -m 644 -D %{SOURCE5} %{buildroot}%{_sysconfdir}/pam.d/vmtoolsd

%post
if [ -f %{_bindir}/vmware-checkvm -a                     \
     -f %{_bindir}/vmhgfs-fuse ] &&                      \
   %{_bindir}/systemd-detect-virt | grep -iq VMware &&   \
   %{_bindir}/vmware-checkvm &> /dev/null &&             \
   %{_bindir}/vmware-checkvm -p | grep -q Workstation && \
   %{_bindir}/vmhgfs-fuse -e &> /dev/null; then
   mkdir -p /mnt/hgfs
fi

if [ "$1" = "2" ]; then
   if [ -f %{_bindir}/vmware-guestproxycerttool ]; then
      %{_bindir}/vmware-guestproxycerttool -e &> /dev/null || /bin/true
   fi
   if [ -d /etc/vmware-tools/GuestProxyData ]; then
      rm -rf /etc/vmware-tools/GuestProxyData &> /dev/null || /bin/true
   fi

   %{_bindir}/systemctl disable vmtoolsd-init.service &> /dev/null || /bin/true
fi
%systemd_post vgauthd.service vmtoolsd.service

%post desktop
%systemd_post run-vmblock\\x2dfuse.mount
if [ -f %{_bindir}/vmware-checkvm ] &&                   \
   %{_bindir}/systemd-detect-virt | grep -iq VMware &&   \
   %{_bindir}/vmware-checkvm &> /dev/null &&             \
   %{_bindir}/vmware-checkvm -p | grep -q Workstation; then
   %{_bindir}/systemctl enable run-vmblock\\x2dfuse.mount &> /dev/null || /bin/true
fi

%post sdmp
if %{_bindir}/systemctl is-active vmtoolsd.service &> /dev/null; then
   %{_bindir}/systemctl restart vmtoolsd.service &> /dev/null || /bin/true
fi

%preun
%systemd_preun vmtoolsd.service vgauthd.service

if [ "$1" = "0" -a                                       \
     -f %{_bindir}/vmware-checkvm ] &&                   \
   %{_bindir}/systemd-detect-virt | grep -iq VMware &&   \
   %{_bindir}/vmware-checkvm &> /dev/null; then

   if [ -f %{_bindir}/vmware-rpctool ]; then
      %{_bindir}/vmware-rpctool 'tools.set.version 0' &> /dev/null || /bin/true
   fi

   if [ -d /mnt/hgfs ] &&                               \
      %{_bindir}/vmware-checkvm -p | grep -q Workstation; then
      umount /mnt/hgfs &> /dev/null || /bin/true
      rmdir /mnt/hgfs &> /dev/null || /bin/true
   fi
fi

%preun desktop
%systemd_preun run-vmblock\\x2dfuse.mount

%postun
%?ldconfig
%systemd_postun_with_restart vmtoolsd.service vgauthd.service

%postun desktop
%systemd_postun run-vmblock\\x2dfuse.mount

%postun sdmp
if [ "$1" = "0" ] &&                                       \
   %{_bindir}/systemctl is-active vmtoolsd.service &> /dev/null; then
   %{_bindir}/systemctl restart vmtoolsd.service &> /dev/null || /bin/true
fi

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%config(noreplace) %{_sysconfdir}/pam.d/*
%dir %{_sysconfdir}/vmware-tools/
%dir %{_sysconfdir}/vmware-tools/vgauth
%dir %{_sysconfdir}/vmware-tools/vgauth/schemas
%config(noreplace) %{_sysconfdir}/vmware-tools/*.conf
%config %{_sysconfdir}/vmware-tools/tools.conf.example
%config %{_sysconfdir}/vmware-tools/vgauth/schemas/*
%{_sysconfdir}/vmware-tools/*-vm-default
%{_sysconfdir}/vmware-tools/scripts
%{_sysconfdir}/vmware-tools/statechange.subr
%{_bindir}/VGAuthService
%{_bindir}/vm-support
%{_bindir}/vmhgfs-fuse
%{_bindir}/vmtoolsd
%{_bindir}/vmware-alias-import
%{_bindir}/vmware-checkvm
%{_bindir}/vmware-hgfsclient
%{_bindir}/vmware-namespace-cmd
%{_bindir}/vmware-rpctool
%{_bindir}/vmware-toolbox-cmd
%{_bindir}/vmware-vgauth-cmd
%{_bindir}/vmware-xferlogs
%{_libdir}/libDeployPkg.so.*
%{_libdir}/libguestlib.so.*
%{_libdir}/libguestStoreClient.so.*
%{_libdir}/libhgfs.so.*
%{_libdir}/libvgauth.so.*
%{_libdir}/libvmtools.so.*
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/common
%{_libdir}/%{name}/plugins/common/*.so
%dir %{_libdir}/%{name}/plugins/vmsvc
%{_libdir}/%{name}/plugins/vmsvc/libappInfo.so
%{_libdir}/%{name}/plugins/vmsvc/libcomponentMgr.so
%{_libdir}/%{name}/plugins/vmsvc/libdeployPkgPlugin.so
%{_libdir}/%{name}/plugins/vmsvc/libgdp.so
%{_libdir}/%{name}/plugins/vmsvc/libguestInfo.so
%{_libdir}/%{name}/plugins/vmsvc/libguestStore.so
%{_libdir}/%{name}/plugins/vmsvc/libpowerOps.so
%{_libdir}/%{name}/plugins/vmsvc/libresolutionKMS.so
%{_libdir}/%{name}/plugins/vmsvc/libtimeSync.so
%{_libdir}/%{name}/plugins/vmsvc/libvmbackup.so
%{_datadir}/%{name}/
%{_udevrulesdir}/99-vmware-scsi-udev.rules
%{_unitdir}/vmtoolsd.service
%{_unitdir}/vgauthd.service
%{_modulesloaddir}/open-vm-tools.conf

%files desktop
%{_sysconfdir}/xdg/autostart/*.desktop
%{_bindir}/vmware-user
%{_bindir}/vmwgfxctrl
%attr(4755,-,-) %{_bindir}/vmware-user-suid-wrapper
%{_bindir}/vmware-vmblock-fuse
%{_libdir}/%{name}/plugins/vmusr/
%{_unitdir}/run-vmblock\x2dfuse.mount

%files sdmp
%{_libdir}/%{name}/plugins/vmsvc/libserviceDiscovery.so
%{_libdir}/%{name}/serviceDiscovery

%ifarch x86_64
%files salt-minion
%dir %{_libdir}/%{name}/componentMgr/
%dir %{_libdir}/%{name}/componentMgr/saltMinion/
%{_libdir}/%{name}/componentMgr/saltMinion/svtminion.sh
%endif

%files devel
%doc docs/api/build/*
%{_includedir}/vmGuestLib/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libDeployPkg.so
%{_libdir}/libguestlib.so
%{_libdir}/libguestStoreClient.so
%{_libdir}/libhgfs.so
%{_libdir}/libvgauth.so
%{_libdir}/libvmtools.so
%{_bindir}/vmware-vgauth-smoketest
%exclude %{_includedir}/libDeployPkg/

%changelog
* Wed Jul 12 2023 Shuo Wang <abushwang@tencent.com> - 12.2.5-1
- update to 12.2.5

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 12.1.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 12.1.0-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Mar 14 2023 Shuo Wang <abushwang@tencent.com> - 12.1.0-1
- initial build
